California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
SENATE DISTRICTS
STATE SENATE 01
CHAVEZ, ANSELMO A. COX, DAVE
| STATE SENATE 03
LENO, MARK MC ENTEE, SASHI MIGDEN, CAROLE NATION, JOE
STATE SENATE 05
AGHAZARIAN, GREG STEBBINS, C. JENNET WOLK, LOIS
| STATE SENATE 07
AMSBERRY, CHRISTIAN A. DE SAULNIER, MARK
STATE SENATE 09
BERMUDEZ, CLAUDIA CHAN, WILMA FEINLAND, MARSHA J. HANCOCK, LONI
| STATE SENATE 11
NATHAN, BLAIR A. SIMITIAN, S. JOSEPH
STATE SENATE 13
ALQUIST, ELAINE CONNOLLY, SHANE PATRICK WEBSTER, JOHN H.
| STATE SENATE 15
FITZGERALD, JIM MALDONADO, ABEL
STATE SENATE 17
MC FARLAND, BRUCE DAVID RUNNER, GEORGE C.
| STATE SENATE 19
JACKSON, HANNAH-BETH STRICKLAND, TONY
STATE SENATE 21
CHOI, TEDDY LIU, CAROL MYERS, STEVEN A.
| STATE SENATE 23
GOLDMAN, COLIN S. LANZI, LEONARD MICHAEL LEVINE, LLOYD MONTAINE, RICHARD E. PAVLEY, FRAN
STATE SENATE 25
BIGGERS, KEVIN J. DEAR, DONALD DYMALLY, MERVYN M. GUTIERREZ, LYDIA A. WRIGHT, RODERICK "ROD"
| STATE SENATE 27
LOWENTHAL, ALAN WOOD, ALLEN G.
STATE SENATE 29
HUFF, ROBERT 'BOB' LYONS, JOSEPH MOUNTJOY, DENNIS STONE, JILL K.
| STATE SENATE 31
DUTTON, BOB FULLER, AMEENAH R.
STATE SENATE 33
PRITCHARD, GARY SIDHU, HARRY
| STATE SENATE 35
HARMAN, TOM MAYER, VIRGINIA GINNY
STATE SENATE 37
BENOIT, JOHN J. BOGH, RUSSELL V. GUERRERO, ARTHUR BRAVO PETERS, DAVID W.
| STATE SENATE 39
KEHOE, CHRISTINE PERWIN, JEFF THOMAS, JESSE
ASSEMBLY DISTRICTS
ASSEMBLY 01
CHESBRO, WESLEY PELL, JAMES J.
| ASSEMBLY 02
MARTINEZ, JOHN F. NIELSEN, JIM SCHAUPP, CHARLES E. SINGH, PAUL R. STIGLICH, PETER V.
ASSEMBLY 03
HARRINGTON, MICHAEL "MICKEY" HORNE, SUE LOGUE, DANIEL R.
| ASSEMBLY 04
CAMPANALE, DENNIS J. GAINES, EDWARD T
ASSEMBLY 05
HUSEN, DOUGLAS LEAHY, DANIEL K. MARTINEZ, KAREN LOIS NIELLO, ROGER THOMPSON, DONALD
| ASSEMBLY 06
HANNAN, TIMOTHY J. HUFFMAN, JARED LAVERY, PAUL
ASSEMBLY 07
EVANS, NOREEN M. GENTRY, DORIS L.
| ASSEMBLY 08
CABALDON, CHRISTOPHER COSME, MANUEL YAMADA, MARIKO M.
ASSEMBLY 09
CURRINGTON, MALI D. FRINK, GERALD ALLEN JONES, DAVE WEBER, C.T.
| ASSEMBLY 10
BONSER, JANICE M. COOK, COLONEL JIM A. HEGYI, PAUL G. HUBER, ALYSON SANDER, DAVID SIEGLOCK, JACK A.
ASSEMBLY 11
HANSEN, ELIZABETH R. TORLAKSON, TOM
| ASSEMBLY 12
APPLEGATE, CONCHITA N. MA, FIONA
ASSEMBLY 13
AMMIANO, TOM DHILLON, HARMEET K.
| ASSEMBLY 14
POLAKOFF, PHILLIP LEE SKINNER, NANCY THURMOND, TONY WORTHINGTON, KRISS
ASSEMBLY 15
BUCHANAN, JOAN FORD, TED KAMENA, SCOTT LLOYD, JUDY BIVIANO RAO, ROBERT WILSON, ABRAM
| ASSEMBLY 16
FAISON, JAMES SWANSON, SANDRE
ASSEMBLY 17
GALGIANI, CATHLEEN MOBLEY JR., JACK M.
| ASSEMBLY 18
FILIPOVICH, LOU HAYASHI, MARY TERAMOTO, JASON K.
ASSEMBLY 19
BRINKMAN, CATHERINE S. GUFLER, ELSIE HILL, JERRY A. HOLOBER, RICHARD PAPAN, GINA PERRY, BRIAN A.
| ASSEMBLY 20
TORRICO, ALBERTO WALD, JEFFREY
ASSEMBLY 21
RUSKIN, IRA YENNE, ANNALISA M.
| ASSEMBLY 22
CASERTA, DOMINIC J. FONG, PAUL OYA, BRENT T. SONG, ANNA WANG, KRIS
ASSEMBLY 23
COTO, JOE PATROSSO, MARK
| ASSEMBLY 24
BEALL, JIM MC NEA, DOUGLAS A.
ASSEMBLY 25
BERRYHILL, TOM WHITE, TAYLOR G.
| ASSEMBLY 26
BERRYHILL, WILLIAM R. EISENHUT, JOHN
ASSEMBLY 27
BARKALOW, STEPHEN DEREK HINKLE, MARK W. A. MONNING, WILLIAM W. MURRAY, ROBERT REILLY, EMILY SPRENGER, BARBARA
| ASSEMBLY 28
CABALLERO, ANNA
ASSEMBLY 29
AVILA, HUMBERTO VILLINES, MICHAEL N.
| ASSEMBLY 30
FLOREZ, FRAN GILMORE, DANNY D.
ASSEMBLY 31
ARAMBULA, JUAN ARCHER, CLIFF
| ASSEMBLY 32
FULLER, JEAN MARTINEZ, VIRGINIA
ASSEMBLY 33
BLAKESLEE, SAM CUTHBERT, ROBERT
| ASSEMBLY 34
CONWAY, CONNIE FARRELLY, DESMOND MAZE, REBECCA SMITH, ROBERT W. ZELLHOEFER, JON W.
ASSEMBLY 35
GANDRUD, GREGORY NAVA, PEDRO I.
| ASSEMBLY 36
CAMPBELL, MAGGIE FOX, STEVE JONES, LINDA K. KNIGHT, STEVE LEDFORD, JAMES C.
ASSEMBLY 37
HARE, DAVID M. MASRY, FERIAL STRICKLAND, AUDRA
| ASSEMBLY 38
LUTNESS, CAROLE L. SMYTH, CAMERON
ASSEMBLY 39
FUENTES, FELIPE LINDBLAD, JOHN P. (JACK) MARTINE, GRADY O. SHAPIRO, LOUIS A.
| ASSEMBLY 40
BLUMENFIELD, BOB BROWN, PAMELA J. CHELEBIAN, ARMINEH HEALEY, LAURETTE MC CRORY, DANIEL R. SHERMAN, KENNETH WALDMAN, STUART
ASSEMBLY 41
BERNSLEY, MARK BROWNLEY, JULIA
| ASSEMBLY 42
FEUER, MICHAEL NELSON SION, STEVEN MARK
ASSEMBLY 43
BARNETT, JANE KREKORIAN, PAUL
| ASSEMBLY 44
FULLER, BRIAN M. LOGAN, THOMAS D. PORTANTINO, ANTHONY
ASSEMBLY 45
ALEXANDER, PHILLIP DE LEON, KEVIN
| ASSEMBLY 46
ALDANA JR., MANUEL ALDAPA, MICHAEL CHAVEZ, ARTURO LARA, RICARDO PEREZ, JOHN A.
ASSEMBLY 47
BASS, KAREN CAGE, LADY
| ASSEMBLY 48
DAVIS, MIKE ESGUERRA, LUCILLA M.
ASSEMBLY 49
ENG, MICHAEL SIEGRIST, ESTHELA G.
| ASSEMBLY 50
DE LA TORRE, HECTOR MILLER, GLADYS O.
ASSEMBLY 51
POLLACK, MAURICE I PRICE, CURREN D. SWINNEY, CARL M. "MARTY"
| ASSEMBLY 52
HALL, ISADORE HARRIS-FORSTER, LINDA LE BLANC, DEBORAH SIMS MARTINEZ, DIANE J. PATRICK, GWEN (BATISTE)
ASSEMBLY 53
LIEU, TED VIDAL, THOMAS H.
| ASSEMBLY 54
HOLT, GABRIELLA S. JACKSON, MICHAEL A. KLING, JOHN WM. LOWENTHAL, BONNIE
ASSEMBLY 55
FURUTANI, WARREN WILLIAMS, EDWIN R.
| ASSEMBLY 56
GARRETT, ROGER H. MENDOZA, TONY
ASSEMBLY 57
HERNANDEZ, EDWARD P. SALDANA, VICTOR
| ASSEMBLY 58
CALDERON, CHARLES M. GETINO, CARLOS A.
ASSEMBLY 59
ADAMS, ANTHONY KEEDY, MAUREEN K. WILLIAMSON, DONALD E.
| ASSEMBLY 60
DICK, LARRY HAGMAN, CURT SINGER, DIANE
ASSEMBLY 61
AVILA, PAUL VINCENT AYALA, MAURICE E. LOPEZ, BENJAMIN I. MAIER, WENDY A. MENDEZ, MICHAEL WHITE, KEN
| ASSEMBLY 62
CARTER, WILMER AMINA NAVARRO, GIL SMITH, JOHN
ASSEMBLY 63
ABRAHAM, JONATHAN EMMERSON, BILL WESTWOOD, MARK DAVID
| ASSEMBLY 64
MC CARTY, KELLY NESTANDE, BRIAN RASSO, PAUL M. TERRELL, DARYL
ASSEMBLY 65
COOK, PAUL J. WOOD, CARL W.
| ASSEMBLY 66
FRANDSEN, GREY JEFFRIES, KEVIN D. KNIGHT, NANCY L.
ASSEMBLY 67
BLOUNT, STEVE SILVA, JAMES W.
| ASSEMBLY 68
ARNOLD, KEN TRAN, VAN
ASSEMBLY 69
MANGELS, CAMERON M. SOLORIO, JOSE
| ASSEMBLY 70
DE VORE, CHARLES S. GLOVER, MICHAEL G.
ASSEMBLY 71
BLAIS, NEIL MILLER, JEFF
| ASSEMBLY 72
DUVALL, MIKE MAC MURRAY, JOHN P.
ASSEMBLY 73
FAVOR, ANDREW H. HARKEY, DIANE JONES, JUDITH E. PATLAN, MARK
| ASSEMBLY 74
GARRICK, MARTIN W. KING, PAUL MAXFIELD, BRETT DEFOREST
ASSEMBLY 75
FLETCHER, NATHAN B. KASAI, DARREN MURPHY, JOHN
| ASSEMBLY 76
BAEHR, DANIEL H. DENNEY, RALPH SALDANA, LORI TRAN, KIM NGOC
ASSEMBLY 77
ANDERSON, JOEL C. BELITZ, RICHARD G. LUTZ, RAYMOND C.
| ASSEMBLY 78
ARABO, AUDAY P. BLOCK, MARTY J. MC CANN, JOHN RICASA, ARLIE SHERARD, MAXINE J.
ASSEMBLY 79
ALBRITTEN, JESSE ROACH, DERRICK SALAS, MARY H.
| ASSEMBLY 80
GONZALES, RICARDO M. GUTIERREZ, RICHARD JEANDRON, GARY PEREZ, V. MANUEL PETTIS, GREGORY S.